==> haskell-smtlib-1.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-smtlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 smtLib
version:              1.1
visibility:           public
id:                   smtLib-1.1-6JJkuW7YCo3ExAL2xJtS4K
key:                  smtLib-1.1-6JJkuW7YCo3ExAL2xJtS4K
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A library for working with the SMTLIB format.
description:          A library for working with the SMTLIB format.
category:             SMT
abi:                  ea08545133cceb887f6af693062da215
exposed:              True
exposed-modules:
    SMTLib1 SMTLib1.QF_AUFBV SMTLib1.QF_BV SMTLib2 SMTLib2.Array
    SMTLib2.BitVector SMTLib2.Compat1 SMTLib2.Core SMTLib2.Int

hidden-modules:       SMTLib1.AST SMTLib1.PP SMTLib2.AST SMTLib2.PP
import-dirs:          /usr/lib/ghc-8.8.3/site-local/smtLib-1.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/smtLib-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/smtLib-1.1
hs-libraries:         HSsmtLib-1.1-6JJkuW7YCo3ExAL2xJtS4K
depends:              base-4.13.0.0 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-smtlib/html/smtLib.haddock
haddock-html:         /usr/share/doc/haskell-smtlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-smtlib-1.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-smtlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 smtLib
version:              1.1
visibility:           public
id:                   smtLib-1.1-AG5K72Ybp1dHToDIozm903
key:                  smtLib-1.1-AG5K72Ybp1dHToDIozm903
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A library for working with the SMTLIB format.
description:          A library for working with the SMTLIB format.
category:             SMT
abi:                  0234c9f1d16d64c791f679baf95d588a
exposed:              True
exposed-modules:
    SMTLib1 SMTLib1.QF_AUFBV SMTLib1.QF_BV SMTLib2 SMTLib2.Array
    SMTLib2.BitVector SMTLib2.Compat1 SMTLib2.Core SMTLib2.Int

hidden-modules:       SMTLib1.AST SMTLib1.PP SMTLib2.AST SMTLib2.PP
import-dirs:          /usr/lib/ghc-8.10.1/site-local/smtLib-1.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/smtLib-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/smtLib-1.1
hs-libraries:         HSsmtLib-1.1-AG5K72Ybp1dHToDIozm903
depends:              base-4.14.0.0 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-smtlib/html/smtLib.haddock
haddock-html:         /usr/share/doc/haskell-smtlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
